==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QEnvironmentLight.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Encapsulate an environment light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html">Qt3DRender::QEnvironmentLight</a></code></p>
 */
public class QEnvironmentLight extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QEnvironmentLight.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::<wbr>irradianceChanged(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyNotify(name="irradiance")
    public final @NonNull Signal1<io.qt.qt3d.render.@Nullable QAbstractTexture> irradianceChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::<wbr>specularChanged(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyNotify(name="specular")
    public final @NonNull Signal1<io.qt.qt3d.render.@Nullable QAbstractTexture> specularChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QEnvironmentLight::<wbr>QEnvironmentLight(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QEnvironmentLight(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QEnvironmentLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::<wbr>irradiance()const</a></code></p>
     */
    @QtPropertyReader(name="irradiance")
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture irradiance(){
        return irradiance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture irradiance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::<wbr>setIrradiance(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyWriter(name="irradiance")
    public final void setIrradiance(io.qt.qt3d.render.@Nullable QAbstractTexture irradiance){
        setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(irradiance));
    }
    
    private native void setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long irradiance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::<wbr>setSpecular(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyWriter(name="specular")
    public final void setSpecular(io.qt.qt3d.render.@Nullable QAbstractTexture specular){
        setSpecular_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(specular));
    }
    
    private native void setSpecular_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long specular);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::<wbr>specular()const</a></code></p>
     */
    @QtPropertyReader(name="specular")
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture specular(){
        return specular_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture specular_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QEnvironmentLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QEnvironmentLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QEnvironmentLight instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QEnvironmentLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QEnvironmentLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #irradiance()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture getIrradiance() {
        return irradiance();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #specular()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture getSpecular() {
        return specular();
    }
}

==> qtjambi-qt3drender-6.6.2-sources.jar: io/qt/qt3d/render/QEnvironmentLight.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Encapsulate an environment light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html">Qt3DRender::QEnvironmentLight</a></code></p>
 */
public class QEnvironmentLight extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QEnvironmentLight.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::<wbr/>irradianceChanged(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyNotify(name="irradiance")
    public final @NonNull Signal1<io.qt.qt3d.render.@Nullable QAbstractTexture> irradianceChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::<wbr/>specularChanged(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyNotify(name="specular")
    public final @NonNull Signal1<io.qt.qt3d.render.@Nullable QAbstractTexture> specularChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QEnvironmentLight::<wbr/>QEnvironmentLight(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QEnvironmentLight(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QEnvironmentLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::<wbr/>irradiance()const</a></code></p>
     */
    @QtPropertyReader(name="irradiance")
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture irradiance(){
        return irradiance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture irradiance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::<wbr/>setIrradiance(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyWriter(name="irradiance")
    public final void setIrradiance(io.qt.qt3d.render.@Nullable QAbstractTexture irradiance){
        setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(irradiance));
    }
    
    private native void setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long irradiance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::<wbr/>setSpecular(Qt3DRender::QAbstractTexture*)</a></code></p>
     */
    @QtPropertyWriter(name="specular")
    public final void setSpecular(io.qt.qt3d.render.@Nullable QAbstractTexture specular){
        setSpecular_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(specular));
    }
    
    private native void setSpecular_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long specular);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::<wbr/>specular()const</a></code></p>
     */
    @QtPropertyReader(name="specular")
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture specular(){
        return specular_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture specular_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QEnvironmentLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QEnvironmentLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QEnvironmentLight instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QEnvironmentLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QEnvironmentLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #irradiance()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture getIrradiance() {
        return irradiance();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #specular()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QAbstractTexture getSpecular() {
        return specular();
    }
}
